<?php

/**
 * Provide a template to display plugin card.
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://wp.solar
 * @since      1.0.0
 *
 * @package    Wp_Solar
 * @subpackage Wp_Solar/admin/partials
 */

$plugin_slug = explode( '/', $plugin['acf']['plugin_main_file'] )[0];
$plugin_link = $plugin['link'];
$plugin_title = $plugin['title']['rendered'];
$plugin_name = explode( ' - ', $plugin['title']['rendered'] )[0];
$plugin_description = $plugin['excerpt']['rendered'];
$plugin_author = ' <cite>' . sprintf( __( 'By %s', 'wp-solar' ), $plugin['acf']['author'] ) . '</cite>';
$plugin_version = $plugin['acf']['version'];
$plugin_file = $plugin['acf']['plugin_main_file'];
$vt_report_uri = $plugin['acf']['vt_report_uri'];

$icon_path = '/wp-content/uploads/update-server/package-assets/icons/';
$plugin_icon_url = WP_SOLAR_SERVER_URL . $icon_path . $plugin_slug . '-256x256.png';
$default_icon_url = WP_SOLAR_SERVER_URL . $icon_path . 'wp-solar-256x256.png';

$action_links = array();
$status = $this->plugin_status( $plugin_file, $plugin_version );

switch ( $status ) {
	case 'install':
		$install_url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=' . $plugin_slug ), 'install-plugin_' . $plugin_slug );
		
		$action_links[] = sprintf(
			'<a class="install-now button" href="%s" aria-label="%s">%s</a>',
			esc_url( $install_url ),
			/* translators: %s: Plugin name. */
			esc_attr( sprintf( _x( 'Install %s now', 'plugin', 'wp-solar' ), $plugin_name ) ),
			__( 'Install Now', 'wp-solar' )
		);
		break;
		
		case 'update_available':
			$update_url = wp_nonce_url( self_admin_url( 'update.php?action=upgrade-plugin&plugin=' . $plugin_file ), 'upgrade-plugin_' . $plugin_file );
			
			$action_links[] = sprintf(
				'<a class="update-now button" href="%s" aria-label="%s">%s</a>',
				esc_url( $update_url ),
				/* translators: %s: Plugin name. */
				esc_attr( sprintf( _x( 'Update %s now', 'plugin', 'wp-solar' ), $plugin_name ) ),
				__( 'Update Now', 'wp-solar' )
			);
			break;
			
			case 'installed';
			$action_links[] = sprintf(
				'<button type="button" class="button button-disabled" disabled="disabled">%s</button>',
				_x( 'Installed', 'plugin', 'wp-solar' )
			);
			break;
		}
		
		$action_links[] = sprintf(
			'<a href="%s" aria-label="%s" title="%s" target="_blank">%s</a>',
			esc_url( $plugin_link ),
			esc_attr( sprintf( __( 'More information about %s', 'wp-soar' ), $plugin_name ) ),
			esc_attr( sprintf( __( 'More information about %s', 'wp-soar' ), $plugin_name ) ),
			__( 'More Details', 'wp-solar' )
		);
		
		$action_links[] = sprintf(
			'<a href="%s" aria-label="%s" title="%s" target="_blank">%s</a>',
			esc_url( $vt_report_uri ),
			esc_attr( sprintf( __( 'VirusTotal report for %s', 'wp-soar' ), $plugin_name ) ),
			esc_attr( sprintf( __( 'VirusTotal report for %s', 'wp-soar' ), $plugin_name ) ),
			__( 'VirusTotal Report', 'wp-solar' )
		);
?>
<div class="plugin-card plugin-card-<?php echo sanitize_html_class( $plugin_slug ); ?>" data-index="<?php echo esc_attr( $index ); ?>">
	<div class="plugin-card-top">
		<div class="name column-name">
			<h3>
				<a href="<?php echo esc_url( $plugin_link ); ?>" target="_blank">
					<?php echo $plugin_title; ?>
					<img src="<?php echo esc_url( $plugin_icon_url ); ?>" class="plugin-icon" alt="" onError="this.onerror=null;this.src='<?php echo esc_url( $default_icon_url ); ?>';"/>
				</a>
			</h3>
		</div>
		<div class="action-links">
			<?php
			if ( $action_links ) {
				echo '<ul class="plugin-action-buttons"><li>' . implode( '</li><li>', $action_links ) . '</li></ul>';
			}
			?>
		</div>
		<div class="desc column-description">
			<p><?php echo $plugin_description; ?></p>
			<p class="authors"><?php echo $plugin_author; ?></p>
		</div>
	</div>
</div>
