<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://wp.solar
 * @since      1.0.0
 *
 * @package    Wp_Solar
 * @subpackage Wp_Solar/admin/partials
 */
?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->

<div class="wrap">
	<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>

	<form method="post" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>">
		<div id="wp-solar-settings-form" class="wp-solar-settings-form">
			<h2><?php esc_html_e( 'Your WP Solar Account', 'wp-solar' ); ?></h2>
 
			<p id="wp-solar-settings-desc">
				<?php esc_html_e( 'In order to download or update resources, you will need a WP Solar account.', 'wp-solar' ); ?>
			</p>

			<?php
				$credentials = self::get_credentials();
				$username = $credentials['username'];
				$password = $credentials['password'];
			?>

			<div class="account-username">
				<label for="username">
					<span class="field-title"><?php esc_html_e( 'Username', 'wp-solar' ); ?></span>
					<input name="username" type="text" id="username" value="<?php echo esc_attr( $username ); ?>" required />
				</label>
			</div>

			<div class="account-password">
				<label for="password">
					<span class="field-title"><?php esc_html_e( 'Password', 'wp-solar' ); ?></span>
					<input name="password" type="password" id="password" value="<?php echo esc_attr( $password ); ?>" required />
				</label>
			</div>

			<?php if ( get_transient( 'wp_solar_api_error' ) ) { ?>
			<p><?php echo esc_html( get_transient( 'wp_solar_api_error' ) ); ?></p>
			<?php
				delete_transient( 'wp_solar_api_error' );
			}
			?>

			<p class="action-buttons">
			<?php
				wp_nonce_field( 'account-credentials', 'wp_solar_nonce' );

				if ( '' !== $username && '' !== $password ) {
					if ( current_time( 'timestamp', 1 ) > $credentials['eot'] ) {
						$result = $this->s2member_op( 'get_user', $username );

						if ( $result && empty( $result['error'] ) ) {
							if ( 0 === $result['level'] ) {
								printf( '<p>%s. <a href="%s" target="_blank">%s</a>.</p>',
									esc_html__( 'You membership expired', 'wp-solar'  ),
									esc_url( WP_SOLAR_SERVER_URL . '/membership/' ),
									esc_html__( 'Renew now', 'wp-solar' )
								);
							} else {
								$credentials['eot'] = $result['s2member_auto_eot_time'];

								update_option( 'wp_solar_account', $credentials );

								printf( '<p>%s %s.</p>',
									esc_html__( 'You membership expires on', 'wp-solar'  ),
									wp_date( get_option( 'date_format' ), $credentials['eot'] )
								);
							}
						}
					} else {
						printf( '<p>%s %s.</p>',
							esc_html__( 'You membership expires on', 'wp-solar'  ),
							wp_date( get_option( 'date_format' ), $credentials['eot'] )
						);
					}

					submit_button( __( 'Log out', 'wp-solar' ), 'primary', 'log-out', false );
				} else {
					submit_button( __( 'Log in', 'wp-solar' ), 'primary', 'log-in', false );
					printf( '<a href="%s" class="button button-primary register" target="_blank">%s</a>',
						esc_url( WP_SOLAR_SERVER_URL . '/membership/' ),
						esc_html__( 'Register', 'wp-solar' )
					);
				}
			?>
			</p>
		</div>
	</form>
</div>
