<?php

/**
 * Provide a template to display theme card.
 *
 * This file is used to markup the admin-facing aspects of the theme.
 *
 * @link       https://wp.solar
 * @since      1.0.0
 *
 * @package    Wp_Solar
 * @subpackage Wp_Solar/admin/partials
 */

$theme_slug = $theme['acf']['theme_slug'];
$theme_link = $theme['link'];
$theme_name = explode( ' - ', $theme['title']['rendered'] )[0];
$theme_author = $theme['acf']['author'];
$screenshot_url = WP_SOLAR_SERVER_URL
. '/wp-content/uploads/update-server/package-assets/'
. $theme_slug . '-screenshot.png';
$theme_version = $theme['acf']['version'];
$theme_preview_uri = $theme['acf']['preview_uri'];
$vt_report_uri = $theme['acf']['vt_report_uri'];

if ( $theme_slug === get_stylesheet() ) {
	$active_class = ' active';
} else {
	$active_class = '';
}
?>
<div class="theme<?php echo $active_class; ?>" data-theme-link="<?php echo esc_url( $theme_link ); ?>" data-index="<?php echo esc_attr( $index ); ?>">
	<?php if ( '' !== $screenshot_url ) { ?>
		<div class="theme-screenshot">
			<img src="<?php echo esc_url( $screenshot_url ); ?>" alt="" />
		</div>
	<?php } else { ?>
		<div class="theme-screenshot blank"></div>
	<?php } ?>

	<?php
		$installed_theme = wp_get_theme( $theme_slug );

		if ( $installed_theme->exists() ) {
			if ( $installed_theme->Version !== $theme_version ) {
				/* translators: %s: Theme name. */
				$aria_label = sprintf( _x( 'Update %s', 'theme', 'wp-solar' ), $theme_name );

				$update_url = add_query_arg(
					array(
						'theme'    => urlencode( $theme_slug ),
						'_wpnonce' => wp_create_nonce( 'upgrade-theme_' . $theme_slug ),
					),
					network_admin_url( 'update.php?action=upgrade-theme' )
				);

				printf(
					'<div class="notice-update-message"><p>%s. <a class="button-link link" href="%s" aria-label="%s">%s</a></p></div>',
					__( 'New version available', 'wp-solar' ),
					esc_url( $update_url ),
					esc_attr( $aria_label ),
					__( 'Update now', 'wp-solar' )
				);
			} else {
				printf(
					'<div class="notice-theme-installed"><p>%s</p></div>',
					_x( 'Installed', 'theme', 'wp-solar' )
				);
			}
		}
	?>

	<span class="more-details">
		<?php _ex( 'Details &amp; Preview', 'theme', 'wp-solar' ); ?>
	</span>

	<?php
		printf(
			'<a class="vt-report button-link" href="%s" aria-label="%s" title="%s" target="_blank">%s</a>',
			esc_url( $vt_report_uri ),
			esc_attr( sprintf( __( 'VirusTotal report for %s', 'wp-soar' ), $theme_name ) ),
			esc_attr( sprintf( __( 'VirusTotal report for %s', 'wp-soar' ), $theme_name ) ),
			'<span class="dashicons dashicons-yes link"></span>'
		);
	?>

	<div class="theme-author">
	<?php
		/* translators: %s: Theme author name. */
		printf( __( 'By %s' ), $theme_author );
	?>
	</div>

	<div class="theme-id-container">
		<h3 class="theme-name"><?php echo $theme_name; ?></h3>

		<div class="theme-actions">
		<?php
			if ( $installed_theme->exists() ) {
				$aria_label = sprintf( _x( 'Activate %s', 'theme', 'wp-solar' ), $theme_name );

				if ( current_user_can( 'switch_themes' ) ) {
					if ( is_multisite() ) {
						$activate_url = add_query_arg(
							array(
								'action'   => 'enable',
								'_wpnonce' => wp_create_nonce( 'enable-theme_' . $theme_slug ),
								'theme'    => $theme_slug,
							),
							network_admin_url( 'themes.php' )
						);
					} else {
						$activate_url = add_query_arg(
							array(
								'action'     => 'activate',
								'_wpnonce'   => wp_create_nonce( 'switch-theme_' . $theme_slug ),
								'stylesheet' => $theme_slug,
							),
							admin_url( 'themes.php' )
						);
					}
				}

				if ( '' != $activate_url ) {
					if ( ! ( $theme_slug === get_stylesheet() ) ) {
						printf(
							'<a class="button button-primary activate link" href="%s" aria-label="%s">%s</a>',
							esc_url( $activate_url ),
							esc_attr( $aria_label ),
							__( 'Activate', 'wp-solar' )
						);
					} else {
						printf(
							'<button class="button button-primary disabled link">%s</button>',
							_x( 'Activated', 'theme', 'wp-solar' )
						);
					}
				}

				$is_block_theme = wp_get_theme( $theme_slug )->is_block_theme();

				if ( ! is_multisite() && current_user_can( 'edit_theme_options' ) && current_user_can( 'customize' ) ) {
					$customize_url = $is_block_theme ? admin_url( 'site-editor.php' ) : wp_customize_url( $theme_slug );
				}

				if ( '' != $customize_url ) {
					if ( ( $theme_slug !== get_stylesheet() ) && ! $is_block_theme ) {
						printf(
							'<a class="button load-customize link" href="%s">%s</a>',
							esc_url( $customize_url ),
							__( 'Live Preview', 'wp-solar' )
						);
					} else {
						printf(
							'<a class="button load-customize link" href="%s">%s</a>',
							esc_url( $customize_url ),
							__( 'Customize', 'wp-solar' )
						);
					}
				}
			} else {
				/* translators: %s: Theme name. */
				$aria_label = sprintf( _x( 'Install %s', 'theme', 'wp-solar' ), $theme_name );

				$install_url = add_query_arg(
					array(
						'theme'    => $theme_slug,
						'_wpnonce' => wp_create_nonce( 'install-theme_' . $theme_slug ),
					),
					network_admin_url( 'update.php?action=install-theme' )
				);

				printf(
					'<a class="button button-primary theme-install link" data-name="%s" data-slug="%s" href="%s" aria-label="%s">%s</a>',
					esc_attr( $theme_name ),
					esc_attr( $theme_slug ),
					esc_url( $install_url ),
					esc_attr( $aria_label ),
					__( 'Install', 'wp-solar' )
				);

				printf(
					'<a class="button preview install-theme-preview link" href="%s" target="_blank">%s</a>',
					esc_url( $theme_preview_uri ),
					__( 'Preview', 'wp-solar' )
				);
			}
		?>
		</div>
	</div>
</div>
