<?php

/**
 * Provide a theme area view for the theme.
 *
 * This file is used to markup the admin-facing aspects of the theme.
 *
 * @link       https://wp.solar
 * @since      1.0.0
 *
 * @package    Wp_Solar
 * @subpackage Wp_Solar/admin/partials
 */
?>

<div class="wrap">
	<h1 class="wp-heading-inline"><?php esc_html_e( 'Premium Themes', 'wp-solar' ); ?></h1>

	<hr class="wp-header-end">

	<h2 class='screen-reader-text'><?php esc_html_e( 'Filter themes list', 'wp-solar' ); ?></h2>

	<div class="wp-filter">
	<?php $term = isset( $_REQUEST['s'] ) ? wp_unslash( $_REQUEST['s'] ) : ''; ?>
		<form class="search-form search-themes" method="get">
			<input type="hidden" name="page" value="wp-solar-themes" />
			<label class="screen-reader-text" for="search-themes"><?php esc_html_e( 'Search Themes', 'wp-solar' ); ?></label>
			<input type="search" name="s" id="search-themes" value="<?php echo esc_attr( $term ); ?>" class="wp-filter-search" placeholder="<?php esc_attr_e( 'Search themes...', 'wp-solar' ); ?>" />
			<?php submit_button( __( 'Search Themes', 'wp-solar' ), 'hide-if-js', false, false, array( 'id' => 'search-submit' ) ); ?>
		</form>
	</div>

	<form id="theme-filter"<?php echo ( '' !== $term ) ? 'class="theme-search"' : '' ?> method="post">
		<?php
		$is_search = false;
		$is_empty = false;

		if ( isset( $term ) && '' !== $term ) {
			$is_search = true;
			$res = $this->themes_api( '', '', $term );
		} else {
			$res = $this->themes_api();
		}

		if ( ! is_wp_error( $res ) ) {
			$this->pagination( 'top', $res['wp-total'], $res['wp-totalpages'] );
		}
		?>

		<div class="wp-list-table widefat theme-browser rendered">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Themes list', 'wp-solar' ); ?></h2>

			<div id="the-list" class="themes wp-clearfix">
			<?php
			if ( ! is_wp_error( $res ) ) {
				if ( $is_search ) {
					if ( ! $res['content'] ) {
						$is_empty = true;
						$this->page_themes_error( $res['content'], $is_empty );
					} else {
						foreach ( $res['content'] as $theme ) {
							echo '<span class="search-item" data-id="' . $theme['id'] . '"></span>';
						}
					}
				} else {
					foreach ( $res['content'] as $index => $theme ) {
						$this->page_theme( $index, $theme );
					}
				}
			} else {
				$this->page_themes_error( $res, $is_empty );
			} ?>
			</div>
		</div>

		<?php
		if ( ! is_wp_error( $res ) ) {
			$this->pagination( 'bottom', $res['wp-total'], $res['wp-totalpages'] );
		}
		?>
	</form>

	<span class="spinner"></span>
</div>